@@ -46,9 +46,9 @@ from treeview import NXTreeView
 from plotview import NXPlotView
 from datadialogs import *
 from scripteditor import ScriptDialog
-from nexpy.api.nexus.tree import (nxload, NeXusError, NXFile, 
-                                  NXobject, NXfield, NXgroup, NXlink,
-                                  NXroot, NXentry)
+import nexpy
+from nexpy.api.nexus import (nxload, NeXusError, NXFile, NXobject, 
+                             NXfield, NXgroup, NXlink, NXroot, NXentry)
 
 # IPython imports
 # require minimum version of IPython for RichIPythonWidget()
@@ -166,7 +166,7 @@ class MainWindow(QtGui.QMainWindow):
         self.file_filter = ';;'.join((
             "NeXus Files (*.nxs *.nx5 *.h5 *.hdf *.hdf5)",
             "Any Files (*.* *)"))
-        self.setWindowTitle('NeXpy')
+        self.setWindowTitle('NeXpy v'+nexpy.__version__)
         self.statusBar().showMessage('Ready')
         self.console._control.setFocus()
 
@@ -1097,7 +1097,7 @@ class MainWindow(QtGui.QMainWindow):
                 except KeyError:
                     raise NeXusError("NeXus item not plottable")
                 from nexpy.gui.plotview import plotview            
-                entry = NXentry(data=plotview.plot.plotdata)
+                entry = NXentry(data=plotview.plotdata)
             if len(entry.data.nxsignal.shape) == 1:
                 dialog = FitDialog(entry, parent=self)
                 dialog.show()
