@@ -25,10 +25,10 @@ Two GUI elements are provided for convenience:
                             This should be placed at the bottom of all import dialogs.
 """
 
-from IPython.external.qt import QtGui
+from PySide import QtGui
+import numpy as np
 
-import numpy as np                  #@UnusedImport
-from nexpy.api.nexus import *       #@UnusedWildImport
+from nexpy.api.nexus import *
 from nexpy.gui.importdialog import BaseImportDialog
 
 filetype = "CBF File"
